# Changelog

## Unreleased

## Version 0.14b0

Released 2020-10-13

- Add timestamps to OTLP exporter
  ([#1199](https://github.com/open-telemetry/opentelemetry-python/pull/1199))
- Update OpenTelemetry protos to v0.5.0
  ([#1143](https://github.com/open-telemetry/opentelemetry-python/pull/1143))

## Version 0.13b0

Released 2020-09-17

- Add instrumentation info to exported spans
  ([#1095](https://github.com/open-telemetry/opentelemetry-python/pull/1095))
- Add metric OTLP exporter
  ([#835](https://github.com/open-telemetry/opentelemetry-python/pull/835))
- Add type hints to OTLP exporter
  ([#1121](https://github.com/open-telemetry/opentelemetry-python/pull/1121))

## Version 0.12b0

- Change package name to opentelemetry-exporter-otlp
  ([#953](https://github.com/open-telemetry/opentelemetry-python/pull/953))
- Update default port to 55680 
  ([#977](https://github.com/open-telemetry/opentelemetry-python/pull/977))

## Version 0.11b0

Released 2020-07-28

- Update span exporter to use OpenTelemetry Proto v0.4.0 ([#872](https://github.com/open-telemetry/opentelemetry-python/pull/889))

## 0.9b0

Released 2020-06-10

- Initial release
